X-Git-Url: https://git.xinqibao.xyz/dwm.git/blobdiff_plain/4b9337a01e7f12058ce54ed65d69e64748397498..9800518ae3505e54c0e52ea3d40050f279e722d6:/dwm.h

diff --git a/dwm.h b/dwm.h
index 999f027..cc8fd1a 100644
--- a/dwm.h
+++ b/dwm.h
@@ -39,7 +39,7 @@ enum { BarTop, BarBot, BarOff };			/* bar position */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
 enum { NetSupported, NetWMName, NetLast };		/* EWMH atoms */
-enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
+enum { WMProtocols, WMDelete, WMName, WMState, WMLast };/* default atoms */
 
 typedef struct Client Client;
 struct Client {
@@ -73,11 +73,6 @@ typedef struct {
 	} font;
 } DC; /* draw context */
 
-typedef struct {
-	const char *symbol;
-	void (*arrange)(void);
-} Layout;
-
 extern const char *tags[];			/* all tags */
 extern char stext[256];				/* status text */
 extern int screen, sx, sy, sw, sh;		/* screen geometry */
@@ -86,12 +81,11 @@ extern unsigned int bh, blw, bpos;		/* bar height, bar layout label width, bar p
 extern unsigned int ntags, numlockmask;		/* number of tags, numlock mask */
 extern void (*handler[LASTEvent])(XEvent *);	/* event handler */
 extern Atom wmatom[WMLast], netatom[NetLast];
-extern Bool selscreen, *seltag;			/* seltag is array of Bool */
+extern Bool selscreen, *seltags;		/* seltags is array of Bool */
 extern Client *clients, *sel, *stack;		/* global client list and stack */
 extern Cursor cursor[CurLast];
 extern DC dc;					/* global draw context */
 extern Display *dpy;
-extern Layout *lt;
 extern Window root, barwin;
 
 /* client.c */
@@ -104,45 +98,46 @@ void killclient(const char *arg);	/* kill sel  nicely */
 void manage(Window w, XWindowAttributes *wa);	/* manage new client */
 void resize(Client *c, int x, int y,
 		int w, int h, Bool sizehints);	/* resize with given coordinates c*/
-void togglefloating(const char *arg);	/* toggles sel between floating/tiled state */
 void unban(Client *c);			/* unbans c */
-void unmanage(Client *c);		/* destroy c */
+void unmanage(Client *c);		/* unmanage c */
 void updatesizehints(Client *c);	/* update the size hint variables of c */
 void updatetitle(Client *c);		/* update the name of c */
 
 /* draw.c */
-void drawstatus(void);			/* draw the bar */
+void drawbar(void);			/* draw the bar */
 void drawtext(const char *text, unsigned long col[ColLast]);	/* draw text */
 unsigned int textw(const char *text);	/* return the width of text in px*/
 
 /* event.c */
 void grabkeys(void);			/* grab all keys defined in config.h */
 
-/* layout.c */
-void floating(void);			/* arranges all windows floating */
-void focusclient(const char *arg);	/* focuses next(1)/previous(-1) visible client */
-void incmasterw(const char *arg);	/* increments the master width with arg's index value */
-void incnmaster(const char *arg);	/* increments nmaster with arg's index value */
-void initlayouts(void);			/* initialize layout array */
-Client *nexttiled(Client *c);		/* returns tiled successor of c */
-void restack(void);			/* restores z layers of all clients */
-void setlayout(const char *arg);	/* sets layout, NULL means next layout */
-void togglebar(const char *arg);	/* shows/hides the bar */
-void togglemax(const char *arg);	/* toggles maximization of floating client */
-void zoom(const char *arg);		/* zooms the focused client to master area, arg is ignored */
-
 /* main.c */
-void updatebarpos(void);		/* updates the bar position */
-void quit(const char *arg);		/* quit dwm nicely */
+Bool gettextprop(Window w, Atom atom,
+		char *text, unsigned int size); /* return text property, UTF-8 compliant */
+void quit(const char *arg);			/* quit dwm nicely */
 int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 
-/* tag.c */
+/* screen.c */
+void applyrules(Client *c);		/* applies rules to c */
+void arrange(void);			/* arranges all windows depending on the layout in use */
 void compileregs(void);			/* initialize regexps of rules defined in config.h */
+void focusnext(const char *arg);	/* focuses next visible client */
+void focusprev(const char *arg);	/* focuses prev visible client */
+const char *getsymbol(void);		/* returns symbol of enabled layout */
+void initlayouts(void);			/* initialize layout array */
+Bool isarrange(void (*func)());		/* returns True if func is the layout function in use */
+Bool isfloating(void);			/* returns True if floating layout is enabled */
 Bool isvisible(Client *c);		/* returns True if client is visible */
-void settags(Client *c, Client *trans);	/* sets tags of c */
+Client *nexttiled(Client *c);		/* returns tiled successor of c */
+void restack(void);			/* restores z layers of all clients */
+void setlayout(const char *arg);	/* sets layout, NULL means next layout */
 void tag(const char *arg);		/* tags sel with arg's index */
+void togglebar(const char *arg);	/* shows/hides the bar */
+void togglefloating(const char *arg);	/* toggles sel between floating/tiled state */
+void togglemax(const char *arg);	/* toggles maximization of floating client */
 void toggletag(const char *arg);	/* toggles sel tags with arg's index */
 void toggleview(const char *arg);	/* toggles the tag with arg's index (in)visible */
+void updatebarpos(void);		/* updates the bar position */
 void view(const char *arg);		/* views the tag with arg's index */
 
 /* util.c */